@@ -62,7 +62,6 @@ sub printmsg {
 ### configuration ###########################################################
 # Include the library for the config file parser
 require '/usr/share/apt-cacher/apt-cacher-lib.pl';
-
 # Read in the config file and set the necessary variables
 
 my $configref;
@@ -74,6 +73,8 @@ my %config = %$configref;
 # not sure what to do if we can't read the config file...
 die "Could not read config file: $@" if $@;
 
+my $globlockfile="$config{cache_dir}/private/exlock";
+
 # check whether we're actually meant to clean the cache
 if ( $config{clean_cache} ne 1 ) {
 	exit 0;
@@ -85,6 +86,11 @@ my $refresh=1;
 
 my %valid;
 
+my $tempdir="$config{cache_dir}/temp";
+mkdir $tempdir if !-d $tempdir;
+die "Could not create tempdir $tempdir\n" if !-d $tempdir;
+unlink (<$tempdir/*>);
+
 ### Preparation of the package lists ########################################
 
 chdir "$config{cache_dir}/packages" && -w "." || die "Could not enter the cache dir";
@@ -104,21 +110,27 @@ sub get {
     print $fh "GET $path_info\r\nConnection: Close\r\n\r\n";
     close($fh);
     if($? && ! $force) {
-        die "Unable to update $path_info . Network problems?\nRun $0 with -v to get more details.\nCleanup aborted.\n";
+        die "Unable to update $path_info . Network problems?\nRun $0 with -v to get more details.\nCleanup aborted since cached data may be damaged.\n";
     }
 }
 
 
 
-my @ifiles=(<*es.gz>, <*es.bz2>, <*es>);
+# file state decissions, lock that area
+open(my $lck, $globlockfile);
+flock($lck, LOCK_EX);
+my @ifiles=(<*es.gz>, <*es.bz2>, <*es>, <*_Index>);
+flock($lck, LOCK_UN);
+close($lck);
+
 for (@ifiles) {
-   printmsg "D: $_\n";
 
    # preserve the index files
    $valid{$_}=1;
 
    # now refresh them, unless disabled by the setting above
    if($refresh) {
+       printmsg "D: $_\n";
       # if the path is stored there, better use that
       if(-s "../private/$_.complete") {
          open(my $tmp, "../private/$_.complete");
@@ -139,8 +151,30 @@ setpriority 0, 0, 20 if $nice_mode;
 
 # use the list of config files we already know
 for my $file (@ifiles) { 
-    printmsg "R: $file\n"; 
-    extract_sums($file, \%valid) || die("Error processing $file in $config{cache_dir}/packages, cleanup stopped\n");
+    printmsg "R: $file\n";
+
+    # get both locks and create a temp. copy
+    my $tmpfile= "$tempdir/$file";
+    open(my $glck, $globlockfile);
+    flock($glck, LOCK_EX);
+    open(my $lck, $file);
+    flock($lck, LOCK_EX);
+    link($file, $tmpfile);
+    flock($lck, LOCK_UN);
+    close($lck);
+    flock($glck, LOCK_UN);
+    close($glck);
+
+    if(-e $tmpfile && ! -s $tmpfile && $tmpfile=~/bz2$/) {
+        # moo, junk, empty file, most likely leftovers from previous versions
+        # of apt-cacher-cleanup where the junk was "protected" from beeing
+        # deleted. Purge later by not having in %valid.
+        # delete $valid{$file}; <- will be recreated RSN either way
+        print "Ignoring empty index file $file, apparently undownloadable\n" if $verbose;
+    }
+    else {
+        extract_sums($tmpfile, \%valid) || die("Error processing $file in $config{cache_dir}/packages, cleanup stopped.\nRemove the file if the repository is no longer interesting and the packages pulled from it are to be removed.\n");
+    }
 }
 
 printmsg "Found ".scalar (keys %valid)." valid file entries\n";
@@ -166,10 +200,11 @@ for(<*.deb>, <*.bz2>, <*.gz>, <*.dsc>) {
    }
 }
 
+# also remove void .complete files, created by broken versions of apt-cacher in rare conditions
 chdir "$config{cache_dir}/private" && -w "." || die "Could not enter the cache dir";
 for(<*.deb.complete>, <*.bz2.complete>, <*.gz.complete>, <*.dsc.complete>) {
    s/.complete$//;
-   if(! defined($valid{$_})) {
+   if(! (defined($valid{$_}) && -e "../packages/$_" && -e "../headers/$_") ) {
       printmsg "Removing: $_.complete\n";
       unlink "$_.complete";
    }
@@ -196,15 +231,17 @@ for(<*>) {
     # must be empty and not complete and beeing downloaded right now
     if(!-s $_) {
         my $fromfile;
-        open($fromfile, $_);
-        if (flock($fromfile, LOCK_EX|LOCK_NB)) {
+        if(open($fromfile, $_) && flock($fromfile, LOCK_EX|LOCK_NB)) {
             # double-check, may have changed while locking
             if(!-s $_) {
                 printmsg "Removing zombie files: $_ and company...\n";
                 unlink $_, "../headers/$_", "../private/$_.complete";
                 flock($fromfile, LOCK_UN);
+                close($fromfile);
             }
         }
     }
 }
 
+unlink (<$tempdir/*>);
+
