@@ -115,20 +115,27 @@ sub make_mask ($$)
 }
 
 sub extract_sums {
-   my $name=shift;
-   $hashref=shift;
+   my ($name, $hashref) = @_;
+   my ($cat, $listpipe, $indexbase);
 
-   my ($cat, $listpipe);
    $cat = ($name=~/bz2$/ ? "bzcat" : ($name=~/gz$/ ? "zcat" : "cat"));
 
-   # lock it or wait
-   open($lck, $name) || return 0;
-   flock($lck, LOCK_EX);
+   if($name=~/^(.*_)Index$/) {
+       $indexbase=$1;
+       $indexbase=~s!.*/!!g;
+   }
 
    open($listpipe, "-|", $cat, $name);
    my $file;
    while(<$listpipe>) {
-      if(/^\s(\w{32})\s\d+\s(\S+)\n/) {
+      if(/^\s(\w{40})\s+\d+\s(\S+)\n/) {
+         $sum=$1;
+         # Index format similar to Sources but filenames need to be corrected
+         # FIXME: this is sha1, not md5. Different format, can be detected by
+         # the length (40), though
+         $file=$indexbase.$2.".gz";
+     }
+     elsif(/^\s(\w{32})\s\d+\s(\S+)\n/) {
          $sum=$1;
          $file=$2;
       }
@@ -145,8 +152,9 @@ sub extract_sums {
          undef $sum;
       }
    };
-   flock($lck, LOCK_UN);
-   return 1;
+   close($listpipe);
+   my $ret = ! ($? >> 8);
+   return $ret;
 }
 
 
@@ -209,6 +217,10 @@ sub check_sum {
    return 1;
 }
 
+# args: filename and sum
+sub store_sum {
+}
+
 
 
 1;
