@@ -11,6 +11,8 @@
 ### configuration ###########################################################
 # Include the library for the config file parser
 require '/usr/share/apt-cacher/apt-cacher-lib.pl';
+use POSIX qw(strftime);
+
 
 # Read in the config file and set the necessary variables
 my $configfile = '/etc/apt-cacher/apt-cacher.conf';
@@ -65,10 +67,11 @@ if (-f "${logfile}") {
 }
 
 #read current time
-($second,$minute,$hour,$day,$month,$year,$null,$null,$null)=localtime(time);
+#($second,$minute,$hour,$day,$month,$year,$null,$null,$null)=localtime(time);
+my $datetime = strftime("%Y-%m-%d %H:%M:%S", localtime());
 
-$year = $year + 1900;
-$month=$month + 1;
+#$year = $year + 1900;
+#$month=$month + 1;
 
 my $hit_count = 0;
 my $hit_bytes = 0;
@@ -202,7 +205,7 @@ $output .= "<p>
 $output .= "<h2 align=\"center\">summary</h2>
 <table border=0 cellpadding=3 cellspacing=1 bgcolor=\"#000000\" align=\"center\" width=\"600\">
 <tr bgcolor=\"#9999cc\"><th bgcolor=\"#9999cc\"> Item </th><th> Value </th></tr>
-<tr bgcolor=\"#cccccc\"><td bgcolor=\"#ccccff\"> Report generated </td><td> $hour:$minute:$second $day/$month/$year </td></tr>
+<tr bgcolor=\"#cccccc\"><td bgcolor=\"#ccccff\"> Report generated </td><td> $datetime </td></tr>
 <tr bgcolor=\"#cccccc\"><td bgcolor=\"#ccccff\"> Administrator </td><td> <a href=\"mailto:$config{admin_email}\">$config{admin_email}</a> </td></tr>";
 $output .= "<tr bgcolor=\"#cccccc\"><td bgcolor=\"#ccccff\"> First request </td><td> $firstrecord </td></tr>";
 $output .= "<tr bgcolor=\"#cccccc\"><td bgcolor=\"#ccccff\"> Last request </td><td> $lastrecord </td></tr>";
