@@ -64,7 +64,8 @@ for ("README", "README.txt") {
    }
 }
 
-foreach my $dir ($config{cache_dir}, $config{logdir}, "$config{cache_dir}/private", "$config{cache_dir}/import", "$config{cache_dir}/packages", "$config{cache_dir}/headers") {
+foreach my $dir ($config{cache_dir}, $config{logdir}, "$config{cache_dir}/private", "$config{cache_dir}/import",
+    "$config{cache_dir}/packages", "$config{cache_dir}/headers", "$config{cache_dir}/temp") {
 	if (!-d $dir) {
 		print "Doing mkdir($dir, 0755)\n";
 		mkdir($dir, 0755);
